import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/SaiSree0122/8f48e13b1fb07bfefac6ea59fadf3df2/raw/b13d5f27b7326d2a6390eb978e777a27da7a74e9/SaleData.csv'
const width = 920;
const height = 522;
const margin = { top: 30, right: 30, bottom: 55, left: 180 };


const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
     // d.Population = +d['1890'];
      return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(0, 11));
    });
  }, []);

  if (!data) {
    return <pre> Loading </pre>;
  }

  const innerHeight = height - margin.top - margin.bottom - 90;
  const innerWidth = width - margin.left - margin.right;

  const yScale = scaleBand()
    .domain(data.map(d => d.Item))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, d => d.Sale_amt)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="orange" />
              <text
              style={{ textAnchor: 'left' }}
              dy=".76em"
              y={innerHeight + 4}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32em"
          
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key={d.Item}
            x={0}
            y={yScale(d.Item)}
            width={xScale(d.Sale_amt)}
            height={yScale.bandwidth()}
        
          />
        ))}
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
